import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:lori_sdk/data/lori_api.dart';
import 'package:lori_sdk/data/models/cart/seller.dart';

class SalesRetailerApi {
  static const API_SELLERS_FOR_RETAILER = '/sales/retailer/sellers';

  Dio _requester;

  SalesRetailerApi({@required Dio requester}) : this._requester = requester;

  Future<ApiCallback<List<Seller>>> getSellers({@required double latitude, @required double longitude}) async {
    try {
      Map<String, dynamic> queryParameters = {
        'lat': latitude,
        'lng': longitude
      };
      var response = await _requester.get(
          API_SELLERS_FOR_RETAILER,
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json)
      );
      var responseData = response.data as List;
      var sellers = List<Seller>();
      for (var row in responseData) {
        sellers.add(Seller.fromJson(row));
      }
      // Callback invocation
      return ApiCallback<List<Seller>>(
          isSuccessful: true, resultData: sellers);
    } on DioError catch (e) {
      return ApiCallback<List<Seller>>().defaultErrorCallback(e);
    }
  }

}